Struct Arguments

1.36.0 · Source
pub struct Arguments<'a> { /* private fields */ }
Available on crate feature wayland and Linux only.
This structure represents a safely precompiled version of a format string and its arguments. This cannot be generated at runtime because it cannot safely be done, so no constructors are given and the fields are private to prevent modification.

The format_args! macro will safely create an instance of this structure. The macro validates the format string at compile-time so usage of the write() and format() functions can be safely performed.

You can use the Arguments<'a> that format_args! returns in Debug and Display contexts as seen below. The example also shows that Debug and Display format to the same thing: the interpolated format string in format_args!.

let debug = format!("{:?}", format_args!("{} foo {:?}", 1, 2));
let display = format!("{}", format_args!("{} foo {:?}", 1, 2));
assert_eq!("1 foo 2", display);
assert_eq!(display, debug);

Implementations

Source

impl<'a> Arguments<'a>

1.52.0 (const: 1.84.0) · Source

pub const fn as_str(&self) -> Option<&'static str>

Gets the formatted string, if it has no arguments to be formatted at runtime.

This can be used to avoid allocations in some cases.

Guarantees

For format_args!("just a literal"), this function is guaranteed to return Some("just a literal").

For most cases with placeholders, this function will return None.

However, the compiler may perform optimizations that can cause this function to return Some(_) even if the format string contains placeholders. For example, format_args!("Hello, {}!", "world") may be optimized to format_args!("Hello, world!"), such that as_str() returns Some("Hello, world!").

The behavior for anything but the trivial case (without placeholders) is not guaranteed, and should not be relied upon for anything other than optimization.

Examples
use std::fmt::Arguments;

fn write_str(_: &str) { /* ... */ }

fn write_fmt(args: &Arguments<'_>) {
    if let Some(s) = args.as_str() {
        write_str(s)
    } else {
        write_str(&args.to_string());
    }
}
assert_eq!(format_args!("hello").as_str(), Some("hello"));
assert_eq!(format_args!("").as_str(), Some(""));
assert_eq!(format_args!("{:?}", std::env::current_dir()).as_str(), None);