Trait Display

1.36.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Available on crate feature wayland and Linux only.
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Implementors



impl Display for cosmic::cosmic_config::Error

Source

impl Display for cosmic::cosmic_theme::palette::rgb::FromHexError

Source

impl Display for cosmic::dialog::file_chooser::Error

Available on crate features xdg-portal or rfd only.


impl Display for SurfaceError



impl Display for cosmic::iced::daemon::program::graphics::core::window::icon::Error



impl Display for cosmic::iced::daemon::program::graphics::core::window::screenshot::CropError



impl Display for cosmic::iced::daemon::program::graphics::Error



impl Display for cosmic::iced::daemon::program::graphics::futures::futures::channel::mpsc::TryRecvError

1.60.0 · Source

impl Display for cosmic::iced::daemon::program::graphics::futures::futures::io::ErrorKind



impl Display for Align



impl Display for Wrap



impl Display for cosmic::iced::daemon::program::graphics::text::cosmic_text::fontdb::Language



impl Display for PaintError



impl Display for DrawError



impl Display for cosmic::iced::daemon::program::graphics::text::cosmic_text::skrifa::outline::error::CffError



impl Display for ToPathError



impl Display for ReadError



impl Display for Opcode



impl Display for cosmic::iced::daemon::program::graphics::text::cosmic_text::skrifa::raw::tables::postscript::Number



impl Display for InvalidTag



impl Display for cosmic::iced::daemon::program::runtime::image::Error



impl Display for HandleError



impl Display for cosmic::iced::ContentFit



impl Display for cosmic::iced::Error

1.34.0 · Source

impl Display for Infallible



impl Display for cosmic::iced::Theme



impl Display for cosmic::iced::window::icon::Error



impl Display for DataOfferError



impl Display for cosmic::cctk::sctk::error::GlobalError



impl Display for Capability



impl Display for SeatError



impl Display for KeyboardError



impl Display for PointerThemeError



impl Display for CreatePoolError



impl Display for PoolError



impl Display for ActivateSlotError



impl Display for CreateBufferError



impl Display for cosmic::cctk::sctk::reexports::calloop::Error



impl Display for CursorIcon



impl Display for cosmic::cctk::sctk::reexports::client::ConnectError



impl Display for cosmic::cctk::sctk::reexports::client::DispatchError



impl Display for cosmic::cctk::sctk::reexports::client::globals::BindError



impl Display for cosmic::cctk::sctk::reexports::client::globals::GlobalError



impl Display for WaylandError



impl Display for CollectionAllocErr

1.86.0 · Source

impl Display for cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::slice::GetDisjointMutError

Source

impl Display for AsciiChar

1.17.0 · Source

impl Display for FromBytesWithNulError

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for SocketAddr

1.29.0 · Source

impl Display for proc_macro::TokenTree

Prints the token tree as a string that is supposed to be losslessly convertible back into the same token tree (modulo spans), except for possibly TokenTree::Groups with Delimiter::None delimiters and negative numeric literals.

Note: the exact form of the output is subject to change, e.g. there might be changes in the whitespace used between tokens. Therefore, you should not do any kind of simple substring matching on the output string (as produced by to_string) to implement a proc macro, because that matching might stop working if such changes happen. Instead, you should work at the TokenTree level, e.g. matching against TokenTree::Ident, TokenTree::Punct, or TokenTree::Literal.

1.0.0 · Source

impl Display for VarError

1.89.0 · Source

impl Display for std::fs::TryLockError

1.15.0 · Source

impl Display for RecvTimeoutError

1.0.0 · Source

impl Display for std::sync::mpsc::TryRecvError

Source

impl Display for hex::error::FromHexError

Source

impl Display for log::Level

Source

impl Display for log::LevelFilter

Source

impl Display for proc_macro2::TokenTree

Prints the token tree as a string that is supposed to be losslessly convertible back into the same token tree (modulo spans), except for possibly TokenTree::Groups with Delimiter::None delimiters and negative numeric literals.

Source

impl Display for ron::error::Error

Source

impl Display for ron::error::Error

Source

impl Display for serde_json::value::Value

Source

impl Display for url::parser::ParseError

Source

impl Display for SyntaxViolation

Source

impl Display for uuid::Variant

Source

impl Display for BernoulliError

Source

impl Display for rand::distr::uniform::Error

Source

impl Display for rand::distr::weighted::Error

1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

1.0.0 · Source

impl Display for f16

1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

1.0.0 · Source

impl Display for i128

1.0.0 · Source

impl Display for isize

Source

impl Display for !

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

1.0.0 · Source

impl Display for u128

1.0.0 · Source

impl Display for usize

Source

impl Display for SliceCastError

Source

impl Display for cosmic::desktop::Mime



impl Display for cosmic::iced::clipboard::mime::Error



impl Display for SmolStr



impl Display for cosmic::iced::daemon::program::graphics::core::theme::Custom



impl Display for cosmic::iced::daemon::program::graphics::futures::futures::channel::mpsc::RecvError



impl Display for cosmic::iced::daemon::program::graphics::futures::futures::channel::mpsc::SendError



impl Display for Canceled



impl Display for EnterError

1.0.0 · Source

impl Display for cosmic::iced::daemon::program::graphics::futures::futures::io::Error



impl Display for Aborted



impl Display for SpawnError



impl Display for ID



impl Display for HintError



impl Display for SvgPen



impl Display for cosmic::iced::daemon::program::graphics::text::cosmic_text::skrifa::raw::collections::int_set::sparse_bit_set::DecodingError



impl Display for cosmic::iced::daemon::program::graphics::text::cosmic_text::skrifa::raw::tables::glyf::bytecode::DecodeError



impl Display for Instruction<'_>



impl Display for NameString<'_>



impl Display for Latin1String<'_>



impl Display for F2Dot14



impl Display for F4Dot12



impl Display for F6Dot10



impl Display for F26Dot6



impl Display for FWord



impl Display for Fixed



impl Display for Int24



impl Display for MajorMinor



impl Display for TryFromGlyphIdError



impl Display for UfWord



impl Display for Uint24



impl Display for Version16Dot16



impl Display for cosmic::iced::daemon::program::graphics::text::cosmic_text::skrifa::string::LocalizedString<'_>



impl Display for NameId



impl Display for GlyphId16



impl Display for GlyphId



impl Display for GlyphName



impl Display for cosmic::iced::daemon::program::graphics::text::cosmic_text::skrifa::Tag



impl Display for Metrics



impl Display for KeyCodeError



impl Display for cosmic::iced::Color



impl Display for cosmic::iced::Radians



impl Display for cosmic::iced::widget::text_input::Value



impl Display for cosmic::iced::window::Id



impl Display for BorderRadii

Source

impl Display for KeyBind



impl Display for cosmic::widget::Id

Source

impl Display for cosmic::widget::text_input::value::Value

Source

impl Display for CaptureSourceError



impl Display for Mode



impl Display for SeatInfo



impl Display for UnknownLayer



impl Display for ChannelError



impl Display for PingError



impl Display for cosmic::cctk::sctk::reexports::csd_frame::CursorIconParseError



impl Display for Interface



impl Display for ProtocolError



impl Display for WEnumError



impl Display for cosmic::cctk::sctk::reexports::client::backend::InvalidId



impl Display for NoWaylandLib



impl Display for cosmic::cctk::sctk::reexports::client::backend::ObjectId

Source

impl Display for AllocError

1.28.0 · Source

impl Display for LayoutError

Source

impl Display for ByteStr

Source

impl Display for ByteString

Source

impl Display for UnorderedKeyError

1.57.0 · Source

impl Display for cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::collections::TryReserveError

1.58.0 · Source

impl Display for FromVecWithNulError

1.7.0 · Source

impl Display for IntoStringError

1.0.0 · Source

impl Display for NulError

1.0.0 · Source

impl Display for ParseBoolError

1.0.0 · Source

impl Display for cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::str::Utf8Error

1.0.0 · Source

impl Display for cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::string::FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.0.0 · Source

impl Display for String

1.35.0 · Source

impl Display for core::array::TryFromSliceError

1.39.0 · Source

impl Display for core::ascii::EscapeDefault

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError

1.34.0 · Source

impl Display for CharTryFromError

1.20.0 · Source

impl Display for ParseCharError

1.9.0 · Source

impl Display for DecodeUtf16Error

1.20.0 · Source

impl Display for core::char::EscapeDebug

1.16.0 · Source

impl Display for core::char::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeUnicode

1.16.0 · Source

impl Display for ToLowercase

1.16.0 · Source

impl Display for ToUppercase

1.59.0 · Source

impl Display for TryFromCharError

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

1.4.0 · Source

impl Display for AddrParseError

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6

1.0.0 · Source

impl Display for core::num::dec2flt::ParseFloatError

1.0.0 · Source

impl Display for ParseIntError

1.34.0 · Source

impl Display for TryFromIntError

1.26.0 · Source

impl Display for Location<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>

1.66.0 · Source

impl Display for TryFromFloatSecsError

Source

impl Display for ExpandError

1.29.0 · Source

impl Display for proc_macro::Group

Prints the group as a string that should be losslessly convertible back into the same group (modulo spans), except for possibly TokenTree::Groups with Delimiter::None delimiters.

1.29.0 · Source

impl Display for proc_macro::Ident

Prints the identifier as a string that should be losslessly convertible back into the same identifier.

1.44.0 · Source

impl Display for proc_macro::LexError

1.29.0 · Source

impl Display for proc_macro::Literal

Prints the literal as a string that should be losslessly convertible back into the same literal (except for possible rounding for floating point literals).

1.29.0 · Source

impl Display for proc_macro::Punct

Prints the punctuation character as a string that should be losslessly convertible back into the same character.

1.15.0 · Source

impl Display for proc_macro::TokenStream

Prints the token stream as a string that is supposed to be losslessly convertible back into the same token stream (modulo spans), except for possibly TokenTree::Groups with Delimiter::None delimiters and negative numeric literals.

Note: the exact form of the output is subject to change, e.g. there might be changes in the whitespace used between tokens. Therefore, you should not do any kind of simple substring matching on the output string (as produced by to_string) to implement a proc macro, because that matching might stop working if such changes happen. Instead, you should work at the TokenTree level, e.g. matching against TokenTree::Ident, TokenTree::Punct, or TokenTree::Literal.

1.65.0 · Source

impl Display for Backtrace

1.0.0 · Source

impl Display for JoinPathsError

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.56.0 · Source

impl Display for WriterPanicked

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>

Source

impl Display for NormalizeError

1.7.0 · Source

impl Display for StripPrefixError

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError

1.0.0 · Source

impl Display for std::sync::mpsc::RecvError

Source

impl Display for WouldBlock

1.26.0 · Source

impl Display for AccessError

1.8.0 · Source

impl Display for SystemTimeError

Source

impl Display for anyhow::Error

Source

impl Display for ParseIntegerError

Source

impl Display for CompressError

Source

impl Display for flate2::mem::DecompressError

Source

impl Display for BVec2

Source

impl Display for BVec3

Source

impl Display for BVec4

Source

impl Display for BVec3A

Source

impl Display for BVec4A

Source

impl Display for Affine2

Source

impl Display for Affine3A

Source

impl Display for Mat3

Source

impl Display for Mat2

Source

impl Display for Mat3A

Source

impl Display for Mat4

Source

impl Display for Quat

Source

impl Display for Vec3A

Source

impl Display for Vec4

Source

impl Display for glam::f32::vec2::Vec2

Source

impl Display for Vec3

Source

impl Display for DAffine2

Source

impl Display for DAffine3

Source

impl Display for DMat2

Source

impl Display for DMat3

Source

impl Display for DMat4

Source

impl Display for DQuat

Source

impl Display for DVec2

Source

impl Display for DVec3

Source

impl Display for DVec4

Source

impl Display for I16Vec2

Source

impl Display for I16Vec3

Source

impl Display for I16Vec4

Source

impl Display for IVec2

Source

impl Display for IVec3

Source

impl Display for IVec4

Source

impl Display for I64Vec2

Source

impl Display for I64Vec3

Source

impl Display for I64Vec4

Source

impl Display for U16Vec2

Source

impl Display for U16Vec3

Source

impl Display for U16Vec4

Source

impl Display for UVec2

Source

impl Display for UVec3

Source

impl Display for UVec4

Source

impl Display for U64Vec2

Source

impl Display for U64Vec3

Source

impl Display for U64Vec4

Source

impl Display for bf16

Source

impl Display for f16

Source

impl Display for log::ParseLevelError

Source

impl Display for SetLoggerError

Source

impl Display for FromStrError

Source

impl Display for num_traits::ParseFloatError

Source

impl Display for proc_macro2::Group

Prints the group as a string that should be losslessly convertible back into the same group (modulo spans), except for possibly TokenTree::Groups with Delimiter::None delimiters.

Source

impl Display for proc_macro2::Ident

Prints the identifier as a string that should be losslessly convertible back into the same identifier.

Source

impl Display for proc_macro2::LexError

Source

impl Display for proc_macro2::Literal

Source

impl Display for proc_macro2::Punct

Prints the punctuation character as a string that should be losslessly convertible back into the same character.

Source

impl Display for proc_macro2::TokenStream

Prints the token stream as a string that is supposed to be losslessly convertible back into the same token stream (modulo spans), except for possibly TokenTree::Groups with Delimiter::None delimiters and negative numeric literals.

Source

impl Display for ron::error::Position

Source

impl Display for ron::error::Span

Source

impl Display for ron::error::SpannedError

Source

impl Display for ron::value::raw::RawValue

Source

impl Display for ron::error::Position

Source

impl Display for ron::error::Span

Source

impl Display for ron::error::SpannedError

Source

impl Display for ron::value::raw::RawValue

Source

impl Display for serde_core::de::value::Error

Source

impl Display for serde_json::error::Error

Source

impl Display for serde_json::number::Number

Source

impl Display for syn::error::Error

Source

impl Display for Lifetime

Source

impl Display for LitFloat

Source

impl Display for LitInt

Source

impl Display for PathPersistError

Source

impl Display for Url

Display the serialization of this URL.

Source

impl Display for uuid::error::Error

Source

impl Display for Braced

Source

impl Display for Hyphenated

Source

impl Display for Simple

Source

impl Display for Urn

Source

impl Display for NonNilUuid

Source

impl Display for Uuid

Source

impl Display for Empty

Source

impl Display for rand_core::os::OsError

1.0.0 · Source

impl Display for Arguments<'_>

1.0.0 · Source

impl Display for cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::fmt::Error



impl Display for AcquireError



impl Display for ActivationToken



impl Display for Address



impl Display for AppID



impl Display for Array<'_>



impl Display for Ast

Print a display representation of this Ast.

This does not preserve any of the original whitespace formatting that may have originally been present in the concrete syntax from which this Ast was generated.

This implementation uses constant stack space and heap space proportional to the size of the Ast.



impl Display for AtspiError



impl Display for Attribute

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Attributes

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Attributes



impl Display for AuthMechanism



impl Display for BStr



impl Display for BStr



impl Display for BString



impl Display for BadAnimation



impl Display for BadIcon



impl Display for BadImage



impl Display for BigEndian



impl Display for BindError



impl Display for BlendOp



impl Display for BlendOp



impl Display for BuildError



impl Display for BuildError



impl Display for BuildError



impl Display for BuildError



impl Display for BuildError



impl Display for BusName<'_>



impl Display for Bytes



impl Display for CacheError



impl Display for CaseFoldError



impl Display for CheckedCastError



impl Display for CmsError



impl Display for Code



impl Display for Color



impl Display for Color



impl Display for ConnectError



impl Display for ConnectionError



impl Display for Connectivity



impl Display for ContentFit



impl Display for ContextError



impl Display for CosmicPanelOuput



impl Display for CropError



impl Display for Custom



impl Display for DataError



impl Display for DataErrorKind



impl Display for DataIdentifierBorrowed<'_>



impl Display for DataLocale

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for DataUrlError



impl Display for Date



impl Display for DateTime



impl Display for DateTime

Converts a DateTime into an ISO 8601 compliant string.

Formatting options supported

  • std::fmt::Formatter::precision can be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.

Example

This shows the default rendering:

use jiff::civil::date;

// No fractional seconds:
let dt = date(2024, 6, 15).at(7, 0, 0, 0);
assert_eq!(format!("{dt}"), "2024-06-15T07:00:00");

// With fractional seconds:
let dt = date(2024, 6, 15).at(7, 0, 0, 123_000_000);
assert_eq!(format!("{dt}"), "2024-06-15T07:00:00.123");

Example: setting the precision

use jiff::civil::date;

let dt = date(2024, 6, 15).at(7, 0, 0, 123_000_000);
assert_eq!(format!("{dt:.6}"), "2024-06-15T07:00:00.123000");
// Precision values greater than 9 are clamped to 9.
assert_eq!(format!("{dt:.300}"), "2024-06-15T07:00:00.123000000");
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(format!("{dt:.0}"), "2024-06-15T07:00:00");


impl Display for DecodeError



impl Display for DecodeError



impl Display for DecodeErrors



impl Display for DecodeErrors



impl Display for DecodeSliceError



impl Display for DecodingError



impl Display for DecodingError



impl Display for DecodingError



impl Display for DecodingError



impl Display for DecodingError



impl Display for DecodingFormatError



impl Display for DecompressError



impl Display for DeserializeError



impl Display for DesktopEntry



impl Display for Device



impl Display for Dict<'_, '_>



impl Display for DispatchError



impl Display for Display



impl Display for DisplayParsingError



impl Display for DisposeOp



impl Display for DisposeOp



impl Display for DlError



impl Display for DocumentID



impl Display for DrmFourcc



impl Display for Elapsed



impl Display for Elapsed



impl Display for EmptyError



impl Display for EncodeSliceError



impl Display for EncodingError



impl Display for EncodingError



impl Display for EncodingError



impl Display for EncodingError



impl Display for EncodingError



impl Display for EncodingFormatError



impl Display for Errno



impl Display for Errno



impl Display for Errno



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for Error



impl Display for ErrorKind



impl Display for ErrorKind



impl Display for ErrorKind



impl Display for ErrorName<'_>



impl Display for Errors



impl Display for EventLoopError



impl Display for EventMaskParseError



impl Display for ExecError



impl Display for Extensions

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for FaceParsingError



impl Display for Fd<'_>



impl Display for Field



impl Display for FieldSet



impl Display for Fields

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for FilterValueListParserError



impl Display for FiniteF32



impl Display for FiniteF64



impl Display for FluentError



impl Display for FontFamily



impl Display for Format



impl Display for FromUtf8Error



impl Display for GenericEntry



impl Display for GetDisjointMutError



impl Display for GetDisjointMutError



impl Display for GetPlanarFramebufferError



impl Display for Gid



impl Display for GroupInfoError



impl Display for Guid<'_>



impl Display for Hir

Print a display representation of this Hir.

The result of this is a valid regular expression pattern string.

This implementation uses constant stack space and heap space proportional to the size of the Hir.



impl Display for I18nEmbedError



impl Display for ISOWeekDate



impl Display for Ibus



impl Display for Id



impl Display for Id



impl Display for Id



impl Display for Id



impl Display for IdsExhausted



impl Display for Image



impl Display for ImageError



impl Display for ImageError



impl Display for ImageFormatHint



impl Display for ImeRequestError



impl Display for In



impl Display for InitError



impl Display for InlinedName



impl Display for InterfaceName<'_>



impl Display for InvalidBase64



impl Display for InvalidBufferSize



impl Display for InvalidFont



impl Display for InvalidId



impl Display for InvalidLength



impl Display for InvalidOutputSize



impl Display for InvalidSetError



impl Display for InvalidStringList



impl Display for JoinError



impl Display for Key



impl Display for Key

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Key

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Keywords

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Language

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Language



impl Display for Language



impl Display for LanguageIdentifier

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for LanguageIdentifier



impl Display for LanguageIdentifierError



impl Display for Level



impl Display for LevelFilter



impl Display for LibxcbLoadError



impl Display for LimitError



impl Display for LittleEndian



impl Display for Locale

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Locale



impl Display for LzwError



impl Display for MatchError



impl Display for MatchError



impl Display for MatchRule<'_>



impl Display for MaxDepthExceeded



impl Display for MemberName<'_>



impl Display for Message



impl Display for Mime



impl Display for MimeParsingError



impl Display for MimeType



impl Display for NamedKey



impl Display for NonZeroPositiveF32



impl Display for NonZeroPositiveF64



impl Display for NormalizedF32



impl Display for NormalizedF64



impl Display for NotSupportedError



impl Display for ObjectId



impl Display for ObjectId



impl Display for ObjectPath<'_>



impl Display for ObjectPathConversionError



impl Display for Offset



impl Display for OpenError



impl Display for Operation



impl Display for Orientation



impl Display for OsError



impl Display for Other

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for OwnedBusName



impl Display for OwnedErrorName



impl Display for OwnedFd



impl Display for OwnedGuid



impl Display for OwnedInterfaceName



impl Display for OwnedMemberName



impl Display for OwnedObjectPath



impl Display for OwnedPropertyName



impl Display for OwnedUniqueName



impl Display for OwnedWellKnownName



impl Display for PanelAnchor



impl Display for PanelSize



impl Display for ParameterError



impl Display for ParameterError



impl Display for ParameterError



impl Display for ParseAlphabetError



impl Display for ParseError



impl Display for ParseError



impl Display for ParseError



impl Display for ParseError



impl Display for ParseLevelError



impl Display for ParseLevelFilterError



impl Display for ParserError



impl Display for PatternIDError



impl Display for PatternIDError



impl Display for PatternSetInsertError



impl Display for PercentEncode<'_>



impl Display for Permission



impl Display for Pid



impl Display for PodCastError



impl Display for Point



impl Display for Point



impl Display for PopError



impl Display for PortalError



impl Display for PositiveF32



impl Display for PositiveF64



impl Display for PreferencesParseError



impl Display for Priority



impl Display for Private

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for PropertyName<'_>



impl Display for PseudoClass<'_>



impl Display for Quality



impl Display for QuoteError



impl Display for Radians



impl Display for Range



impl Display for RangeError



impl Display for Rational



impl Display for Rect



impl Display for Rect



impl Display for RecvError



impl Display for RecvError



impl Display for RecvError



impl Display for RecvError



impl Display for RecvError



impl Display for Regex



impl Display for Regex



impl Display for Region

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Region



impl Display for ReleaseNameReply



impl Display for ReplyError



impl Display for ReplyOrIdError



impl Display for RequestError



impl Display for RequestNameReply



impl Display for ResponseError



impl Display for ReuniteError



impl Display for ReuniteError



impl Display for Role



impl Display for SRational



impl Display for Script

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Script



impl Display for Script



impl Display for ScriptExtension



impl Display for Selector<'_>



impl Display for SerializeError



impl Display for SetGlobalDefaultError



impl Display for SetOn



impl Display for Signature



impl Display for SignedDuration



impl Display for Size



impl Display for Size



impl Display for SmallIndexError



impl Display for SoftBufferError



impl Display for SourceRange



impl Display for Span



impl Display for StartError



impl Display for StartError



impl Display for StartServiceReply



impl Display for State



impl Display for StateIDError



impl Display for StateIDError



impl Display for Str<'_>



impl Display for StrContext



impl Display for StrContextValue



impl Display for Stretch



impl Display for StringStorage<'_>



impl Display for Structure<'_>



impl Display for Style



impl Display for StyleSheet<'_>



impl Display for SubdivisionId

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for SubdivisionSuffix

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Subtag

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Subtag

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for SvgParseError



impl Display for SvgParseError



impl Display for TaffyError



impl Display for Tag



impl Display for Tag



impl Display for Tcp



impl Display for TcpTransportFamily



impl Display for TextDomainError



impl Display for TextPos



impl Display for TextPos



impl Display for Theme



impl Display for Time

Converts a Time into an ISO 8601 compliant string.

Formatting options supported

  • std::fmt::Formatter::precision can be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.

Example

use jiff::civil::time;

// No fractional seconds:
let t = time(7, 0, 0, 0);
assert_eq!(format!("{t}"), "07:00:00");

// With fractional seconds:
let t = time(7, 0, 0, 123_000_000);
assert_eq!(format!("{t}"), "07:00:00.123");

Example: setting the precision

use jiff::civil::time;

let t = time(7, 0, 0, 123_000_000);
assert_eq!(format!("{t:.6}"), "07:00:00.123000");
// Precision values greater than 9 are clamped to 9.
assert_eq!(format!("{t:.300}"), "07:00:00.123000000");
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(format!("{t:.0}"), "07:00:00");


impl Display for Timestamp

Converts a Timestamp datetime into a RFC 3339 compliant string.

Since a Timestamp never has an offset associated with it and is always in UTC, the string emitted by this trait implementation uses Z for “Zulu” time. The significance of Zulu time is prescribed by RFC 9557 and means that “the time in UTC is known, but the offset to local time is unknown.” If you need to emit an RFC 3339 compliant string with a specific offset, then use [Timestamp::display_with_offset].

Formatting options supported

  • std::fmt::Formatter::precision can be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.

Example

This shows the default rendering:

use jiff::Timestamp;

// No fractional seconds.
let ts = Timestamp::from_second(1_123_456_789)?;
assert_eq!(format!("{ts}"), "2005-08-07T23:19:49Z");

// With fractional seconds.
let ts = Timestamp::new(1_123_456_789, 123_000_000)?;
assert_eq!(format!("{ts}"), "2005-08-07T23:19:49.123Z");

Example: setting the precision

use jiff::Timestamp;

let ts = Timestamp::new(1_123_456_789, 123_000_000)?;
assert_eq!(
    format!("{ts:.6}"),
    "2005-08-07T23:19:49.123000Z",
);
// Precision values greater than 9 are clamped to 9.
assert_eq!(
    format!("{ts:.300}"),
    "2005-08-07T23:19:49.123000000Z",
);
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(
    format!("{ts:.0}"),
    "2005-08-07T23:19:49Z",
);


impl Display for TimestampDisplayWithOffset



impl Display for Transform

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for TransformOriginError



impl Display for Transport



impl Display for TryAcquireError



impl Display for TryCurrentError



impl Display for TryFromExtendedColorError



impl Display for TryFromSliceError



impl Display for TryGetError



impl Display for TryLockError



impl Display for TryRecvError



impl Display for TryRecvError



impl Display for TryRecvError



impl Display for TryRecvError



impl Display for TryRecvError



impl Display for TryReserveError



impl Display for TryReserveError



impl Display for Uid



impl Display for UleError



impl Display for UnexpectedIconError



impl Display for Unicode

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for UnicodeWordBoundaryError



impl Display for UnicodeWordError



impl Display for UniqueName<'_>



impl Display for Unix



impl Display for UnixSocket



impl Display for Unixexec



impl Display for UnrecognizedCodeError



impl Display for UnrecognizedFourcc



impl Display for UnrecognizedModifier



impl Display for UnrecognizedNamedKeyError



impl Display for UnrecognizedVendor



impl Display for UnsupportedError



impl Display for UsbError



impl Display for Utf8CharsError



impl Display for Utf8Error



impl Display for Value

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Value

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Value<'_>



impl Display for ValueSet<'_>



impl Display for Variant

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Variant



impl Display for Variants

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.



impl Display for Vec2



impl Display for Vec2



impl Display for VideoMode



impl Display for ViewBoxError



impl Display for Weight



impl Display for WellKnownName<'_>



impl Display for WindowIdentifier



impl Display for ZeroTrieBuildError



impl Display for Zoned

Converts a Zoned datetime into a RFC 9557 compliant string.

Formatting options supported

  • std::fmt::Formatter::precision can be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.

Example

This shows the default rendering:

use jiff::civil::date;

// No fractional seconds:
let zdt = date(2024, 6, 15).at(7, 0, 0, 0).in_tz("US/Eastern")?;
assert_eq!(format!("{zdt}"), "2024-06-15T07:00:00-04:00[US/Eastern]");

// With fractional seconds:
let zdt = date(2024, 6, 15).at(7, 0, 0, 123_000_000).in_tz("US/Eastern")?;
assert_eq!(format!("{zdt}"), "2024-06-15T07:00:00.123-04:00[US/Eastern]");

Example: setting the precision

use jiff::civil::date;

let zdt = date(2024, 6, 15).at(7, 0, 0, 123_000_000).in_tz("US/Eastern")?;
assert_eq!(
    format!("{zdt:.6}"),
    "2024-06-15T07:00:00.123000-04:00[US/Eastern]",
);
// Precision values greater than 9 are clamped to 9.
assert_eq!(
    format!("{zdt:.300}"),
    "2024-06-15T07:00:00.123000000-04:00[US/Eastern]",
);
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(
    format!("{zdt:.0}"),
    "2024-06-15T07:00:00-04:00[US/Eastern]",
);
Source

impl Display for dyn Expected + '_



impl Display for dyn Value

Source

impl<'a> Display for Unexpected<'a>

1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

1.34.0 · Source

impl<'a> Display for cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::str::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::str::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::str::EscapeUnicode<'a>

Source

impl<'a> Display for Name<'a>

Source

impl<'a> Display for ParseBuffer<'a>



impl<'a> Display for EscapeBytes<'a>



impl<'a> Display for LanguageRange<'a>



impl<'a> Display for LocalizedString<'a>



impl<'a, 'e, E> Display for Base64Display<'a, 'e, E>
where E: Engine,

Source

impl<'a, K, V> Display for std::collections::hash::map::OccupiedError<'a, K, V>
where K: Debug, V: Debug,

Source

impl<'a, K, V, A> Display for cosmic::cctk::sctk::reexports::client::backend::smallvec::alloc::collections::btree_map::OccupiedError<'a, K, V, A>
where K: Debug + Ord, V: Debug, A: Allocator + Clone,



impl<'a, R, G, T> Display for MappedReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,



impl<'a, R, G, T> Display for ReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for MappedMutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for MappedRwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for MappedRwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for MutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for RwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgrade + 'a, T: Display + 'a + ?Sized,



impl<'a, R, T> Display for RwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,



impl<'a, T> Display for MappedMutexGuard<'a, T>
where T: Display + ?Sized,



impl<'a, T> Display for RwLockMappedWriteGuard<'a, T>
where T: Display + ?Sized,



impl<'a, T> Display for RwLockReadGuard<'a, T>
where T: Display + ?Sized,



impl<'a, T> Display for RwLockWriteGuard<'a, T>
where T: Display + ?Sized,



impl<'d> Display for TimeZoneName<'d>



impl<'f> Display for Display<'f>



impl<'n> Display for Pieces<'n>



impl<'s, T> Display for SliceVec<'s, T>
where T: Display,



impl<A> Display for ArrayVec<A>
where A: Array, <A as Array>::Item: Display,



impl<A> Display for TinyVec<A>
where A: Array, <A as Array>::Item: Display,



impl<A, B> Display for Concat<A, B>
where A: Writeable, B: Writeable,



impl<A, S, V> Display for ConvertError<A, S, V>
where A: Display, S: Display, V: Display,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,

Source

impl<E> Display for Report<E>
where E: Error,



impl<E> Display for DecodeError<E>
where E: Display,



impl<E> Display for ErrMode<E>
where E: Debug,



impl<E> Display for Error<E>
where E: Display,

Source

impl<F> Display for PersistError<F>

Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,



impl<I> Display for InputError<I>
where I: Clone + Display,

The Display implementation allows the std::error::Error implementation



impl<I> Display for LocatingSlice<I>
where I: Display,



impl<I> Display for Partial<I>
where I: Display,



impl<I> Display for TreeErrorBase<I>
where I: Display,



impl<I, C> Display for TreeError<I, C>
where I: Display, C: Display,



impl<I, C> Display for TreeErrorContext<I, C>
where I: Display, C: Display,



impl<I, E> Display for ParseError<I, E>
where I: AsBStr, E: Display,



impl<I, S> Display for Stateful<I, S>
where I: Display,



impl<Id, Fd> Display for Argument<Id, Fd>
where Id: Display, Fd: AsRawFd,



impl<K, V, S, A> Display for OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<K, V, S, A> Display for OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,



impl<O> Display for F32<O>
where O: ByteOrder,



impl<O> Display for F64<O>
where O: ByteOrder,



impl<O> Display for I16<O>
where O: ByteOrder,



impl<O> Display for I32<O>
where O: ByteOrder,



impl<O> Display for I64<O>
where O: ByteOrder,



impl<O> Display for I128<O>
where O: ByteOrder,



impl<O> Display for Isize<O>
where O: ByteOrder,



impl<O> Display for U16<O>
where O: ByteOrder,



impl<O> Display for U32<O>
where O: ByteOrder,



impl<O> Display for U64<O>
where O: ByteOrder,



impl<O> Display for U128<O>
where O: ByteOrder,



impl<O> Display for Usize<O>
where O: ByteOrder,

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,

Source

impl<S> Display for Host<S>
where S: AsRef<str>,



impl<S> Display for Ascii<S>
where S: Display,



impl<S> Display for UniCase<S>
where S: Display,



impl<Src, Dst> Display for AlignmentError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.



impl<Src, Dst> Display for SizeError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.



impl<Src, Dst> Display for ValidityError<Src, Dst>
where Dst: KnownLayout + TryFromBytes + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<T> Display for std::sync::mpmc::error::SendTimeoutError<T>

1.0.0 · Source

impl<T> Display for std::sync::mpsc::TrySendError<T>

1.0.0 · Source

impl<T> Display for std::sync::poison::TryLockError<T>

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,

Source

impl<T> Display for BoxedSliceCastError<T>

Source

impl<T> Display for VecCastError<T>

Source

impl<T> Display for OutOfBounds<T>



impl<T> Display for cosmic::iced::daemon::program::graphics::futures::futures::channel::mpsc::TrySendError<T>



impl<T> Display for cosmic::iced::daemon::program::graphics::futures::futures::io::ReuniteError<T>



impl<T> Display for IntSet<T>
where T: Domain + Display,



impl<T> Display for cosmic::iced::daemon::program::graphics::text::cosmic_text::skrifa::raw::types::BigEndian<T>
where T: Display + Scalar + Copy,



impl<T> Display for cosmic::iced::Point<T>
where T: Display,

Source

impl<T> Display for CapacityError<T>



impl<T> Display for InsertError<T>

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for core::cell::Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for NonZero<T>

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,

1.10.0 · Source

impl<T> Display for Wrapping<T>
where T: Display,

1.0.0 · Source

impl<T> Display for std::sync::mpsc::SendError<T>

Source

impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for PoisonError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,



impl<T> Display for AsyncFdTryNewError<T>



impl<T> Display for Bgr<T>
where T: Display,



impl<T> Display for BitFlags<T>
where T: BitFlag + Debug,



impl<T> Display for CachePadded<T>
where T: Display,



impl<T> Display for DisplayValue<T>
where T: Display,



impl<T> Display for ForcePushError<T>



impl<T> Display for FromBitsError<T>
where T: BitFlag + Debug,



impl<T> Display for LossyWrap<T>
where T: TryWriteable,



impl<T> Display for MutexGuard<'_, T>
where T: Display + ?Sized,



impl<T> Display for OwnedMutexGuard<T>
where T: Display + ?Sized,



impl<T> Display for OwnedRwLockWriteGuard<T>
where T: Display + ?Sized,



impl<T> Display for Point<T>
where T: Display,



impl<T> Display for PushError<T>



impl<T> Display for Rgb<T>
where T: Display,



impl<T> Display for SendError<T>



impl<T> Display for SendError<T>



impl<T> Display for SendError<T>



impl<T> Display for SendError<T>



impl<T> Display for SendError<T>



impl<T> Display for SendTimeoutError<T>



impl<T> Display for SetError<T>



impl<T> Display for SetOnceError<T>



impl<T> Display for Setting<T>
where T: Display,



impl<T> Display for TrySendError<T>



impl<T> Display for TrySendError<T>



impl<T> Display for TrySendError<T>



impl<T> Display for TryWriteableInfallibleAsWriteable<T>
where T: TryWriteable<Error = Infallible>,



impl<T> Display for Unalign<T>
where T: Unaligned + Display,



impl<T> Display for WithPart<T>
where T: Writeable + ?Sized,

1.0.0 · Source

impl<T, A> Display for Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,



impl<T, A> Display for Bgra<T, A>
where T: Display, A: Display,



impl<T, A> Display for Rgba<T, A>
where T: Display, A: Display,



impl<T, B> Display for Ref<B, T>
where B: ByteSlice, T: FromBytes + Display + KnownLayout + Immutable + ?Sized,



impl<T, E> Display for TryChunksError<T, E>
where E: Display,



impl<T, E> Display for TryReadyChunksError<T, E>
where E: Display,



impl<T, Item> Display for cosmic::iced::daemon::program::graphics::futures::futures::prelude::stream::ReuniteError<T, Item>



impl<T, S> Display for ArcSwapAny<T, S>
where S: Strategy<T>, T: Display + RefCnt,



impl<T, S> Display for Guard<T, S>
where T: Display + RefCnt, S: Strategy<T>,



impl<T, U> Display for OwnedMappedMutexGuard<T, U>
where U: Display + ?Sized, T: ?Sized,



impl<T, U> Display for OwnedRwLockMappedWriteGuard<T, U>
where U: Display + ?Sized, T: ?Sized,



impl<T, U> Display for OwnedRwLockReadGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

1.0.0 · Source

impl<W> Display for IntoInnerError<W>



impl<Y, C> Display for Yoke<Y, C>
where Y: for<'a> Yokeable<'a>, <Y as Yokeable<'a>>::Output: for<'a> Display,

Source

impl<const CAP: usize> Display for ArrayString<CAP>



impl<const N: usize> Display for TinyAsciiStr<N>